diff --git a/src/winio.c b/src/winio.c
index b7246f1fe0f925932a10cff8a0ee3fde0ebea25c..f14ca2747d11889957d4e92c2b1f472c779abb7d 100644
--- a/src/winio.c
+++ b/src/winio.c
@@ -2866,12 +2866,12 @@ void edit_redraw(const filestruct *old_current, size_t old_pww)
 
 #ifndef NANO_TINY
 	/* If the mark is on, update all the lines between the old last
 	 * line of the edit window and current. */
 	if (openfile->mark_set) {
-	    while (foo != openfile->current) {
+	    while (foo != openfile->edittop) {
 		update_line(foo, 0);
 
-		foo = (foo->lineno > openfile->current->lineno) ?
+		foo = (foo->lineno > openfile->edittop->lineno) ?
 			foo->prev : foo->next;
 	    }
 	}
@@ -2866,12 +2866,12 @@ void edit_redraw(const filestruct *old_current, size_t old_pww)
 #ifndef NANO_TINY
 	/* If the mark is on, update all the lines between the old last
-	 * line of the edit window and current. */
+	 * line of the edit window and edittop. */
 	if (openfile->mark_set) {